@@ -75,25 +75,39 @@ pub fn rand_bool() -> bool {
     fastbool()
 }
 
-/// Returns true if n is even and false if n is odd.
-pub fn is_even(n: u128) -> bool {
+fn is_even(n: u128) -> bool {
     n % 2 == 0
 }
 
+/// Returns true if n is odd and false if n is even.
+fn is_even_any(n: &dyn ToString) -> bool {
+    is_even(n.to_string().parse::<u128>().unwrap())
+}
+
 fn mock_refstr(s: &str, randomize: bool) -> String {
     let mut res: String = String::new();
 
     for (i, c) in s.chars().enumerate() {
+        let c_high: char = c.to_ascii_uppercase();
+        let c_low: char = c.to_ascii_lowercase();
+
+        /*
+            let i_as_u128: u128 = match i.to_string().parse::<u128>() {
+                Ok(i) => i,
+                Err(_) => panic!("Error converting i to u128"),
+            };
+        */
+
         if randomize {
             if rand_bool() {
-                res.push(c.to_ascii_uppercase());
+                res.push(c_high);
             } else {
-                res.push(c.to_ascii_lowercase());
+                res.push(c_low);
             }
-        } else if is_even(i.try_into().unwrap()) {
-            res.push(c.to_ascii_uppercase());
+        } else if is_even_any(&i) {
+            res.push(c_high);
         } else {
-            res.push(c.to_ascii_lowercase());
+            res.push(c_low);
         }
     }
     res
@@ -170,11 +184,26 @@ mod tests {
 
     #[test]
     fn test_is_even_even() {
-        assert_eq!(is_even(2), true);
+        assert!(is_even(2));
     }
 
     #[test]
     fn test_is_even_odd() {
-        assert_eq!(is_even(3), false);
+        assert!(!is_even(3));
+    }
+
+    #[test]
+    fn test_is_even_any_even() {
+        assert!(is_even_any(&2));
+    }
+
+    #[test]
+    fn test_is_even_any_odd() {
+        assert!(!is_even_any(&3));
+    }
+
+    #[test]
+    fn test_is_even_any_string() {
+        assert!(is_even_any(&"2"));
     }
 }
